@@ -52,6 +52,7 @@ test.american.Haug <- function() {
     checkEquals(AO(type="put", strike=  100.00, underl=  90.00, div= 0.10, riskF= 0.10, mat= 0.50, vol= 0.35)$value, 14.6945, tol=1.0e-3)
     checkEquals(AO(type="put", strike=  100.00, underl= 100.00, div= 0.10, riskF= 0.10, mat= 0.50, vol= 0.35)$value,  9.5104, tol=1.0e-3)
     checkEquals(AO(type="put", strike=  100.00, underl= 110.00, div= 0.10, riskF= 0.10, mat= 0.50, vol= 0.35)$value,  5.8823, tol=1.0e-3)
+
 }
 
 ## Asian option tests
@@ -63,6 +64,7 @@ test.asian <- function() {
     checkEquals(AO(averageType="geometric", typ="put", strike=85, underl=80, div=-0.03, riskF=0.05, mat=0.25, vol=0.20)$value, 4.6922, tol=1.0e-4)
 
     if (!.onWindows) {
+        
         ## data from "Asian Option", Levy, 1997
         ## in "Exotic Options: The State of the Art",
         ## edited by Clewlow, Strickland
@@ -195,7 +197,6 @@ test.binary <- function() {
     checkEquals(rc[1:7],
                 list(value=2.671045, delta=-0.1060594, gamma=0.00310624, vega=8.153881, theta=-1.742309, rho=-9.9577, divRho=7.9544),
                 tolerance=1.0e-5)
-    return()
 }
 
 ## European option tests based on Haug's book
@@ -252,3 +253,15 @@ test.european.Haug <- function() {
     checkEquals(EO(type="put",  strike=100.00, underl=110.00, div= 0.10, riskF=0.10, mat=0.50, vol=0.35)$value,  5.7963, tol=1.0e-3)
     checkEquals(EO(type="call", strike=40.00,  underl=42.00,  div= 0.08, riskF=0.04, mat=0.75, vol=0.35)$value,  5.0975, tol=1.0e-3)
 }
+
+## European and American option tests with discrete dividends based on Hull's book
+test.discreteDividend.Hull <- function() {
+    AO <- AmericanOption                # shorthand
+    EO <- EuropeanOption                # shorthand
+    ## Reference p. 253 - Hull 5th ed. Exercise 12.8 - From QuantLib tests
+    checkEquals(EO(type="call", underlying=40, strike=40, div=0, riskFree=0.09, maturity=0.5, vol=0.3,
+                   discreteDividends = c(0.5, 0.5), discreteDividendsTimeUntil = c(2/12, 5/12))$value, 3.67, tol=1.0e-2)
+    ## Reference p. 256 - Hull 5th ed. Exercise 12.9 using (flawed) Roll, Geske and Whaley formula
+    checkEquals(AO(type="call", underlying=40, strike=40, div=0, riskFree=0.09, maturity=0.5, vol=0.3, engine = "CrankNicolson",
+                   discreteDividends = c(0.5, 0.5), discreteDividendsTimeUntil = c(2/12, 5/12))$value, 3.72, tol=1.0e-1)
+}
\ No newline at end of file
